@@ -19,6 +19,7 @@ class PyTorchLightningTest(unittest.TestCase):
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
+            deployment='d1',
             debug_mode=True)
 
     def tearDown(self):
@@ -45,8 +46,6 @@ class PyTorchLightningTest(unittest.TestCase):
                 super().__init__()
                 self.batch_size = BATCH_SIZE
                 self.l1 = torch.nn.Linear(28 * 28, 10)
-                self.train_acc = Accuracy()
-                self.test_acc = Accuracy()
 
             def forward(self, x):
                 return torch.relu(self.l1(x.view(x.size(0), -1)))
@@ -55,17 +54,11 @@ class PyTorchLightningTest(unittest.TestCase):
                 x, y = batch
                 preds = self(x)
                 loss = F.cross_entropy(preds, y)
-                self.train_acc(preds, y)
-                self.log('train_acc', self.train_acc, on_step=True, on_epoch=False)
                 return loss
 
-            def test_step(self, batch, batch_nb):
+            def predict_step(self, batch, batch_nb):
                 x, y = batch
-                preds = self(x)
-                loss = F.cross_entropy(preds, y)
-                self.test_acc(preds, y)
-                self.log('test_acc', self.test_acc, on_step=True, on_epoch=False)
-                return loss
+                return self(x)
 
             def train_dataloader(self):
                 train_ds = MNIST(PATH_DATASETS, train=True, download=True, transform=transforms.ToTensor())
@@ -73,11 +66,11 @@ class PyTorchLightningTest(unittest.TestCase):
                 train_loader = DataLoader(train_ds, batch_size=self.batch_size)
                 return train_loader
 
-            def test_dataloader(self):
-                test_ds = MNIST(PATH_DATASETS, train=False, download=True, transform=transforms.ToTensor())
-                test_ds = torch.utils.data.Subset(test_ds, torch.arange(1000))
-                test_loader = DataLoader(test_ds, batch_size=self.batch_size)
-                return test_loader
+            def predict_dataloader(self):
+                predict_ds = MNIST(PATH_DATASETS, train=False, download=True, transform=transforms.ToTensor())
+                predict_ds = torch.utils.data.Subset(predict_ds, torch.arange(1000))
+                predict_loader = DataLoader(predict_ds, batch_size=self.batch_size)
+                return predict_loader
 
             def configure_optimizers(self):
                 return torch.optim.Adam(self.parameters(), lr=0.02)
@@ -88,47 +81,28 @@ class PyTorchLightningTest(unittest.TestCase):
             accelerator='gpu' if torch.cuda.is_available() else 'cpu',
             devices=AVAIL_GPUS,
             max_epochs=1,
-            callbacks=[GraphsignalCallback(endpoint='ep1')]
+            callbacks=[GraphsignalCallback()]
         )
 
         trainer.tune(mnist_model)
 
         trainer.fit(mnist_model)
 
-        trainer.test(mnist_model)
+        trainer.predict(mnist_model)
 
         signal = mocked_upload_signal.call_args[0][0]
 
         #pp = pprint.PrettyPrinter()
         #pp.pprint(MessageToJson(signal))
 
-        self.assertEqual(signal.endpoint_name, 'ep1')
-
-        self.assertTrue(
-            signal.agent_info.framework_profiler_type, 
-            signals_pb2.AgentInfo.ProfilerType.PYTORCH_LIGHTNING_PROFILER)
+        self.assertEqual(signal.endpoint_name, 'predict_batch')
 
         self.assertEqual(
-            signal.frameworks[-1].type,
+            signal.frameworks[0].type,
             signals_pb2.FrameworkInfo.FrameworkType.PYTORCH_LIGHTNING_FRAMEWORK)
-        self.assertTrue(signal.frameworks[-1].version.major > 0)
+        self.assertTrue(signal.frameworks[0].version.major > 0)
 
         self.assertEqual(
             signal.model_info.model_format,
             signals_pb2.ModelInfo.ModelFormat.PYTORCH_FORMAT)
         self.assertTrue(signal.model_info.model_size_bytes > 0)
-
-        test_op_stats = None
-        for op_stats in signal.op_stats:
-            if op_stats.op_name == 'aten::addmm':
-                test_op_stats = op_stats
-                break
-        self.assertIsNotNone(test_op_stats)
-        self.assertTrue(test_op_stats.count >= 1)
-        import torch
-        if torch.cuda.is_available():
-            self.assertTrue(test_op_stats.total_device_time_us >= 1)
-            self.assertTrue(test_op_stats.self_device_time_us >= 1)
-        else:
-            self.assertTrue(test_op_stats.total_host_time_us >= 1)
-            self.assertTrue(test_op_stats.self_host_time_us >= 1)
