@@ -3,12 +3,12 @@ import functools
 
 import graphsignal
 from graphsignal.proto import signals_pb2
-from graphsignal.data.data_profiler import DataProfiler, add_counts
+from graphsignal.data.base_data_profiler import BaseDataProfiler, DataStats
 
 logger = logging.getLogger('graphsignal')
 
 
-class TorchTensorProfiler(DataProfiler):
+class TorchTensorProfiler(BaseDataProfiler):
     def __init__(self):
         super().__init__()
 
@@ -16,7 +16,7 @@ class TorchTensorProfiler(DataProfiler):
         torch = self.check_module('torch')
         return torch is not None and torch.is_tensor(data)
 
-    def compute_counts(self, data):
+    def compute_stats(self, data):
         torch = self.check_module('torch')
         counts = {}
         counts['element_count'] = data.nelement()
@@ -26,12 +26,4 @@ class TorchTensorProfiler(DataProfiler):
         counts['zero_count'] = int(torch.count_nonzero(torch.eq(data, 0)))
         counts['negative_count'] = int(torch.count_nonzero(torch.lt(data, 0)))
         counts['positive_count'] = int(torch.count_nonzero(torch.gt(data, 0)))
-        return counts
-
-    def build_stats(self, data):
-        counts = self.compute_counts(data)
-        data_stats = signals_pb2.DataStats()
-        data_stats.data_type = 'torch.Tensor'
-        data_stats.shape[:] = list(data.size())
-        add_counts(data_stats, counts)
-        return data_stats
\ No newline at end of file
+        return DataStats(type_name='torch.Tensor', shape=list(data.size()), counts=counts)
